@@ -553,7 +553,7 @@ back to the user from the mailer."
       (or (buffer-modified-p)
           (y-or-n-p "Message already sent; resend? ")))
       (progn
-	(expand-abbrev)			; for mail-abbrevs
+	(if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
 	(run-hooks 'mail-send-hook)
 	(message "Sending...")
 	(funcall send-mail-function)
@@ -977,19 +977,19 @@ back to the user from the mailer."
 (defun mail-to ()
   "Move point to end of To-field."
   (interactive)
-  (expand-abbrev)
+  (if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
   (mail-position-on-field "To"))
 
 (defun mail-subject ()
   "Move point to end of Subject-field."
   (interactive)
-  (expand-abbrev)
+  (if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
   (mail-position-on-field "Subject"))
 
 (defun mail-cc ()
   "Move point to end of CC-field.  Create a CC field if none."
   (interactive)
-  (expand-abbrev)
+  (if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
   (or (mail-position-on-field "cc" t)
       (progn (mail-position-on-field "to")
 	     (insert "\nCC: "))))
@@ -997,7 +997,7 @@ back to the user from the mailer."
 (defun mail-bcc ()
   "Move point to end of BCC-field.  Create a BCC field if none."
   (interactive)
-  (expand-abbrev)
+  (if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
   (or (mail-position-on-field "bcc" t)
       (progn (mail-position-on-field "to")
 	     (insert "\nBCC: "))))
@@ -1005,7 +1005,7 @@ back to the user from the mailer."
 (defun mail-fcc (folder)
   "Add a new FCC field, with file name completion."
   (interactive "FFolder carbon copy: ")
-  (expand-abbrev)
+  (if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
   (or (mail-position-on-field "fcc" t)	;Put new field after exiting FCC.
       (mail-position-on-field "to"))
   (insert "\nFCC: " folder))
@@ -1013,7 +1013,7 @@ back to the user from the mailer."
 (defun mail-reply-to ()      
   "Move point to end of Reply-To-field.  Create a Reply-To field if none."
   (interactive)
-  (expand-abbrev)
+  (if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
   (or (mail-position-on-field "reply-to" t)
       (progn (mail-position-on-field "to")
 	     (insert "\nReply-To: "))))
@@ -1040,7 +1040,7 @@ back to the user from the mailer."
 (defun mail-text ()
   "Move point to beginning of message text."
   (interactive)
-  (expand-abbrev)
+  (if (interactive-p) (expand-abbrev))  ; for mail-abbrevs
   (goto-char (point-min))
   (search-forward (concat "\n" mail-header-separator "\n")))
 
